@@ -21,13 +21,19 @@
 #' sample(1:10,10,replace=TRUE) %.%unique__cumsum
 #' sample(1:10,10,replace=TRUE) %.%unique__cumsum__length
 #'
+#'
+#' # set sep before function chaining
+#' chain_sep("X")
+#' sample(1:10,10,replace=TRUE) %.%uniqueXcumsum
 #' @export
 
 `%.%` <- function(obj, funcs){
   sep. <- options()$quickcode_chain_sep %or% "\\.\\."
   .pF <- as.character(substitute(funcs))
   .pF2 <- trimws(strsplit(.pF,sep.)[[1]])
-  lapply(.pF2, function(l) eval(parse(text = paste0("obj<<- ",l,"(obj)"))))
+
+  for(u in .pF2) obj<- do.call(u,list(obj))
+  #lapply(.pF2, function(l) eval(parse(text = paste0("obj<<- ",l,"(obj)"))))
   obj
 }
 
